==> owncloud-8.2.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files/l10n/ka_GE.js <==
OC.L10N.register(
    "files",
    {
    "Unknown error" : "უცნობი შეცდომა",
    "Could not move %s - File with this name already exists" : "%s –ის გადატანა ვერ მოხერხდა – ფაილი ამ სახელით უკვე არსებობს",
    "Could not move %s" : "%s –ის გადატანა ვერ მოხერხდა",
    "No file was uploaded. Unknown error" : "ფაილი არ აიტვირთა. უცნობი შეცდომა",
    "There is no error, the file uploaded with success" : "ჭოცდომა არ დაფიქსირდა, ფაილი წარმატებით აიტვირთა",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "ატვირთული ფაილი აჭარბებს upload_max_filesize დირექტივას php.ini ფაილში",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "ატვირთული ფაილი აჭარბებს  MAX_FILE_SIZE დირექტივას, რომელიც მითითებულია HTML ფორმაში",
    "The uploaded file was only partially uploaded" : "ატვირთული ფაილი მხოლოდ ნაწილობრივ აიტვირთა",
    "No file was uploaded" : "ფაილი არ აიტვირთა",
    "Missing a temporary folder" : "დროებითი საქაღალდე არ არსებობს",
    "Failed to write to disk" : "შეცდომა დისკზე ჩაწერისას",
    "Not enough storage available" : "საცავში საკმარისი ადგილი არ არის",
    "Invalid directory." : "დაუშვებელი დირექტორია.",
    "Files" : "ფაილები",
    "Favorites" : "ფავორიტები",
    "Home" : "სახლი",
    "Close" : "დახურვა",
    "Upload cancelled." : "ატვირთვა შეჩერებულ იქნა.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "მიმდინარეობს ფაილის ატვირთვა. სხვა გვერდზე გადასვლა გამოიწვევს ატვირთვის შეჩერებას",
    "Actions" : "მოქმედებები",
    "Download" : "ჩამოტვირთვა",
    "Rename" : "გადარქმევა",
    "Delete" : "წაშლა",
    "Details" : "დეტალური ინფორმაცია",
    "Pending" : "მოცდის რეჟიმში",
    "Error" : "შეცდომა",
    "{new_name} already exists" : "{new_name} უკვე არსებობს",
    "Name" : "სახელი",
    "Size" : "ზომა",
    "Modified" : "შეცვლილია",
    "New" : "ახალი",
    "File name cannot be empty." : "ფაილის სახელი არ შეიძლება იყოს ცარიელი.",
    "Your storage is full, files can not be updated or synced anymore!" : "თქვენი საცავი გადაივსო. ფაილების განახლება და სინქრონიზირება ვერ მოხერხდება!",
    "Your storage is almost full ({usedSpacePercent}%)" : "თქვენი საცავი თითქმის გადაივსო ({usedSpacePercent}%)",
    "Favorite" : "ფავორიტი",
    "Upload" : "ატვირთვა",
    "Text file" : "ტექსტური ფაილი",
    "Folder" : "საქაღალდე",
    "New folder" : "ახალი ფოლდერი",
    "File handling" : "ფაილის დამუშავება",
    "Maximum upload size" : "მაქსიმუმ ატვირთის ზომა",
    "max. possible: " : "მაქს. შესაძლებელი:",
    "Save" : "შენახვა",
    "Settings" : "პარამეტრები",
    "WebDAV" : "WebDAV",
    "Cancel upload" : "ატვირთვის გაუქმება",
    "Upload too large" : "ასატვირთი ფაილი ძალიან დიდია",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "ფაილის ზომა რომლის ატვირთვასაც თქვენ აპირებთ, აჭარბებს სერვერზე დაშვებულ მაქსიმუმს.",
    "Files are being scanned, please wait." : "მიმდინარეობს ფაილების სკანირება, გთხოვთ დაელოდოთ.",
    "Upload cancelled." : "ატვირთვა შეჩერებულ იქნა."
},
"nplurals=1; plural=0;");

==> owncloud-9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files/l10n/ka_GE.js <==
OC.L10N.register(
    "files",
    {
    "Unknown error" : "უცნობი შეცდომა",
    "No file was uploaded. Unknown error" : "ფაილი არ აიტვირთა. უცნობი შეცდომა",
    "There is no error, the file uploaded with success" : "ჭოცდომა არ დაფიქსირდა, ფაილი წარმატებით აიტვირთა",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "ატვირთული ფაილი აჭარბებს upload_max_filesize დირექტივას php.ini ფაილში",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "ატვირთული ფაილი აჭარბებს  MAX_FILE_SIZE დირექტივას, რომელიც მითითებულია HTML ფორმაში",
    "The uploaded file was only partially uploaded" : "ატვირთული ფაილი მხოლოდ ნაწილობრივ აიტვირთა",
    "No file was uploaded" : "ფაილი არ აიტვირთა",
    "Missing a temporary folder" : "დროებითი საქაღალდე არ არსებობს",
    "Failed to write to disk" : "შეცდომა დისკზე ჩაწერისას",
    "Not enough storage available" : "საცავში საკმარისი ადგილი არ არის",
    "Invalid directory." : "დაუშვებელი დირექტორია.",
    "Files" : "ფაილები",
    "Favorites" : "ფავორიტები",
    "Home" : "სახლი",
    "Close" : "დახურვა",
    "Upload cancelled." : "ატვირთვა შეჩერებულ იქნა.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "მიმდინარეობს ფაილის ატვირთვა. სხვა გვერდზე გადასვლა გამოიწვევს ატვირთვის შეჩერებას",
    "Actions" : "მოქმედებები",
    "Download" : "ჩამოტვირთვა",
    "Rename" : "გადარქმევა",
    "Delete" : "წაშლა",
    "Unshare" : "გაუზიარებადი",
    "Details" : "დეტალური ინფორმაცია",
    "Pending" : "მოცდის რეჟიმში",
    "Name" : "სახელი",
    "Size" : "ზომა",
    "Modified" : "შეცვლილია",
    "New" : "ახალი",
    "File name cannot be empty." : "ფაილის სახელი არ შეიძლება იყოს ცარიელი.",
    "Your storage is full, files can not be updated or synced anymore!" : "თქვენი საცავი გადაივსო. ფაილების განახლება და სინქრონიზირება ვერ მოხერხდება!",
    "Your storage is almost full ({usedSpacePercent}%)" : "თქვენი საცავი თითქმის გადაივსო ({usedSpacePercent}%)",
    "Favorite" : "ფავორიტი",
    "Folder" : "საქაღალდე",
    "New folder" : "ახალი ფოლდერი",
    "Upload" : "ატვირთვა",
    "File handling" : "ფაილის დამუშავება",
    "Maximum upload size" : "მაქსიმუმ ატვირთის ზომა",
    "max. possible: " : "მაქს. შესაძლებელი:",
    "Save" : "შენახვა",
    "Settings" : "პარამეტრები",
    "WebDAV" : "WebDAV",
    "Cancel upload" : "ატვირთვის გაუქმება",
    "Upload too large" : "ასატვირთი ფაილი ძალიან დიდია",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "ფაილის ზომა რომლის ატვირთვასაც თქვენ აპირებთ, აჭარბებს სერვერზე დაშვებულ მაქსიმუმს.",
    "Text file" : "ტექსტური ფაილი"
},
"nplurals=1; plural=0;");
